<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Http;
use App\Models\Payment;

class PaymentController extends Controller
{
    public function store(Request $request)
{
    $validated = $request->validate([
        'firstname'     => 'required|string|min:2|max:100|regex:/^[a-zA-Z\s]+$/',
        'amount'        => 'required|numeric|min:1|max:100000',
        'email'         => 'required|email',
        'phone'         => 'required|digits_between:10,15|regex:/^[0-9]+$/',
        'productinfo'   => 'nullable|alpha_num|size:10',
        'country_code'  => 'required|string|max:5', // Now explicitly required
    ], [
        'firstname.required'     => 'Name is required.',
        'firstname.min'          => 'Name must be at least 2 characters.',
        'firstname.regex'        => 'Name must contain only letters and spaces.',
        
        'amount.required'        => 'Amount is required.',
        'amount.numeric'         => 'Amount must be a number.',
        'amount.min'             => 'Minimum donation is ₹1.',
        'amount.max'             => 'Maximum donation is ₹100000.',

        'email.required'         => 'Email is required.',
        'email.email'            => 'Enter a valid email address.',

        'phone.required'         => 'Mobile number is required.',
        'phone.digits_between'   => 'Mobile number must be between 10 and 15 digits.',
        'phone.regex'            => 'Mobile number must be numeric only.',

        'productinfo.alpha_num'  => 'PAN must be alphanumeric.',
        'productinfo.size'       => 'PAN must be exactly 10 characters.',

        'country_code.required'  => 'Country code is required.',
    ]);

    $txn_id = 'TXN_' . strtoupper(Str::random(10));

    // Save to the database
    $payment = Payment::create([
        'user_name'     => $validated['firstname'],
        'mobile'        => $validated['phone'],
        'country_code'  => $validated['country_code'],
        'email'         => $validated['email'],
        'amount'        => $validated['amount'],
        'panno'         => $validated['productinfo'] ?? null,
        'txn_id'        => $txn_id,
        'status'        => 'pending'
    ]);

    // Prepare API payload
    $apiPayload = [
        "user_name"     => $validated['firstname'],
        "mobile"        => $validated['phone'],
        "country_code"  => $validated['country_code'],
        "email"         => $validated['email'],
        "amount"        => $validated['amount']
    ];

    // Make API call
    $response = Http::post('https://furevverhome.com/public/api/furevverhome-paymentlink', $apiPayload);

    if ($response->successful()) {
        $data = $response->json();

        $payment->payment_link = $data['payment_link'] ?? null;
        $payment->save();

        return redirect()->route('payment.success')->with('message', 'Payment initiated. Please proceed using the payment link.');
    } else {
        return back()->withErrors(['api' => 'Failed to initiate payment link. Please try again.']);
    }
}
}
