<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use App\Mail\WelcomeEmail;


class UserController extends Controller
{

    public function createUser(Request $request)
    {
        // Validate the incoming request
        $request->validate([
            'email' => 'required|email|unique:users,email',
            'password' => 'required|min:8',
            'name' => 'required|string|max:255',
        ]);

        // Create a new user with the validated data
        $user = User::create([
            'email' => $request->email,
            'role' => 'astrologer',  // Assuming the default role is 'astrologer'
            'password' => Hash::make($request->password),  // Store hashed password
            'name' => $request->name,
            'is_verified' => 1,  // Set is_verified to 1 (verified)
        ]);

        // Send the welcome email with credentials
       Mail::to($request->email)->send(new WelcomeEmail($user));

        // Return success response
        return response()->json([
            'status' => true,
            'message' => 'User created and email sent successfully!',
            'user_id' => $user->id
        ]);
    }

    public function studentRegister(Request $request)
    {
        $request->validate([
            'name' => 'string|required|min:2',
            'email' => 'string|email|required|max:100|unique:users',
            'password' => 'string|required|confirmed|min:6'
        ]);

        $user = new User;
        $user->name = $request->name;
        $user->email = $request->email;
        $user->password = Hash::make($request->password);
        $user->is_verified = '1';
        $user->save();

        return redirect('/dashboard/users');
    }

    public function forgotPassword(Request $request)
{
    // Validate the form inputs
    $validated = $request->validate([
        'email' => 'required|email|exists:users,email', // Email must exist in users table
        'newPassword' => 'required|min:4',  // Password confirmation
    ]);

    // If validation fails, it will automatically redirect back with errors, no need for additional handling here.

    // Find user by email
    $user = User::where('email', $request->email)->first();

    if ($user) {
        // Hash the new password
        $user->password = bcrypt($request->newPassword);

        // Save the updated user data
        $user->save();

        // Return success message
        return back()->with('success', 'Password reset successful. You can now login with your new password.');
    } else {
        // Return an error message if user is not found
        return response()->json(['error' => 'No account found with that email address.'], 404);
    }
}
    public function userLogin(Request $request)
    {
        $request->validate([
            'email' => 'string|required|email',
            'password' => 'string|required'
        ]);

        $userCredential = $request->only('email', 'password');
        $userData = User::where('email', $request->email)->first();

        if ($userData && $userData->is_verified == 0) {
            $this->sendOtp($userData);
            return redirect("/verification/" . $userData->id);
        } elseif (Auth::attempt($userCredential)) {
            $role = Auth::user()->role;
            if ($role === 'admin') {
                return redirect('/dashboard');
            } elseif ($role === 'astrologer') {
                return redirect('/astrologerdashboard');
            } elseif ($role === 'user') {
                return redirect('/');
            } else {
                return redirect('/')->with('error', 'Access denied.');
            }
        } else {
            return back()->withErrors(['email' => 'Email & Password is incorrect']);
        }
    }

    public function loadDashboard()
    {
        if (Auth::user()) {
            return view('dashboard.dashboard');
        }
        return redirect('/login');
    }

    public function loadAppointmentDashboard()
    {
        if (Auth::user()) {
            return view('dashboard.appointmentReport');
        }
        return redirect('/login');
    }
    public function logout(Request $request)
    {
        $request->session()->flush();
        Auth::logout();
        return redirect('/');
    }

}
